<div align="center">

<h1>
    <img width="500" align="center" src="https://raw.githubusercontent.com/lento234/wordlebee/main/assets/wordlebee-logo.svg">
</h1>

[![PyPi Version](https://img.shields.io/pypi/v/wordlebee.svg?style=flat-square&labelColor=000000)](https://pypi.org/project/wordlebee/)
[![PyPi Python versions](https://img.shields.io/pypi/pyversions/wordlebee.svg?style=flat-square&labelColor=000000)](https://pypi.org/project/wordlebee/)
![License](https://img.shields.io/github/license/lento234/wordlebee?style=flat-square&color=blue&labelColor=000000)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg?style=flat-square&labelColor=000000)](#black)
[![Downloads](https://static.pepy.tech/personalized-badge/wordlebee?period=total&units=international_system&left_color=black&right_color=blue&left_text=Downloads)](https://pepy.tech/project/wordlebee)

***A cli wordle word guessing helper bee to solve the wordle puzzle of the day.***

</div>

## Usage

```
python -m wordlebee
```

## Installation

Install `wordlebee` in isolated environment:

```
pipx install wordlebee
```

Install `wordlebee`:

```
pip install wordlebee
```

## Development

Install conda enviroment:

```
conda env create -f environment.yml
```

Install using `poetry`:

```
poetry install
```
